@@ -7,18 +7,18 @@
 import numpy as np
 
 from xicsrt.tools.xicsrt_doc import dochelper
-from xicsrt.optics._XicsrtOpticGeneric import XicsrtOpticGeneric
+from xicsrt.optics._InteractNone import InteractNone
+from xicsrt.optics._ShapePlane import ShapePlane
 
 @dochelper
 
-class XicsrtOpticAperture(XicsrtOpticGeneric):
+class XicsrtOpticAperture(InteractNone, ShapePlane):
     """
     An optic that can be used to set an aperture.
 
     Programming Notes
     -----------------
-
-    All of the implementation for the aperture is in :any:`XicsrtOpticGeneric`,
+    All of the implementation for the aperture is in :any:`TraceObject`,
     so nothing is needed in this subclass for the time being.
     """
 
