@@ -21,29 +21,35 @@ from xicsrt import xicsrt_config
 from xicsrt.tools import xicsrt_misc
 from xicsrt.util import profiler
 
+log = logging.getLogger(__name__)
+
 def load_config(filename):
     config = _dict_from_file(filename)
     return config
 
 
-def save_config(config, filename=None, path=None):
+def save_config(config, filename=None, path=None, mkdir=None):
     if filename is None:
         filename = generate_filename(config, kind='config', path=path)
-    _file_from_dict(config, filename, mkdir=config['general']['make_directories'])
+    if mkdir is None:
+        mkdir = config['general'].get('make_directories', False)
+    _file_from_dict(config, filename, mkdir=mkdir)
 
     filename = pathlib.Path(filename).expanduser().resolve()
-    logging.info('Config saved to {}'.format(filename))
+    log.info('Config saved to {}'.format(filename))
 
 
-def save_results(output, filename=None, path=None):
+def save_results(output, filename=None, path=None, mkdir=None):
     config = output['config']
     _make_output_path(config)
     if filename is None:
         filename = generate_filename(config, kind='results', path=path)
-    _file_from_dict(output, filename, mkdir=config['general']['make_directories'])
+    if mkdir is None:
+        mkdir = config['general'].get('make_directories', False)
+    _file_from_dict(output, filename, mkdir=mkdir)
 
     filename = pathlib.Path(filename).expanduser().resolve()
-    logging.info('History saved to {}'.format(filename))
+    log.info('History saved to {}'.format(filename))
 
 
 def load_results(config=None, filename=None, path=None):
@@ -53,19 +59,21 @@ def load_results(config=None, filename=None, path=None):
     return output
 
 
-def save_images(output, rotate=False, path=None):
+def save_images(output, rotate=True, path=None, mkdir=None):
     """
     Save images from the raytracing output.
     """
     from PIL import Image
 
     config = output['config']
+    if mkdir is None:
+        mkdir = config['general'].get('make_directories', False)
 
     for key_opt in output['config']['optics']:
         if key_opt in output['total']['image']:
             if output['total']['image'][key_opt] is not None:
                 filename = generate_filename(output['config'], 'image', key_opt, path=path)
-                if config['general']['make_directories']:
+                if mkdir:
                     _make_path(filename)
 
                 image_temp = output['total']['image'][key_opt]
@@ -76,7 +84,7 @@ def save_images(output, rotate=False, path=None):
                 generated_image.save(filename)
 
                 filename = pathlib.Path(filename).expanduser().resolve()
-                logging.info('Saved image: {}'.format(filename))
+                log.info('Saved image: {}'.format(filename))
 
 
 def generate_filename(config, kind=None, name=None, path=None):
@@ -164,7 +172,7 @@ def _make_output_path(config):
         path = pathlib.Path(config['general']['output_path']).expanduser()
         if not path.exists():
             path.mkdir(parents=True, exist_ok=True)
-            logging.info(f'Made directory: {path}')
+            log.info(f'Made directory: {path}')
 
 
 def _make_path(filename):
@@ -173,7 +181,7 @@ def _make_path(filename):
         path = path.parent
     if not path.exists():
         path.mkdir(parents=True, exist_ok=True)
-        logging.info(f'Made directory: {path}')
+        log.info(f'Made directory: {path}')
 
 
 def path_exists(path):
